@@ -327,7 +327,7 @@ def rich_pdb_klass(base, is_celery=False, context=None, show_layouts=True):
 
         def displayhook(self, obj):
             if obj is not None:
-                self._print(repr(obj))
+                self._print(obj if isinstance(obj, (dict, list)) else repr(obj))
 
         def error(self, msg):
             self._print(msg, prefix="***", style="danger", print_layout=False)
@@ -430,7 +430,9 @@ def rich_pdb_klass(base, is_celery=False, context=None, show_layouts=True):
                     print_layout=False,
                 )
 
-            if base == Pdb or is_celery:
+            if is_celery:
+                Pdb.print_stack_entry(self, frame_lineno, prompt_prefix)
+            elif base == Pdb:
                 print_syntax(frame_lineno, prompt_prefix)
             else:
                 print_syntax(frame_lineno, "", context)
